@@ -25,7 +25,6 @@ import (
 	"encoding/json"
 	"errors"
 	"io"
-	"io/ioutil"
 	"net/http"
 	"net/url"
 	"os"
@@ -274,7 +273,7 @@ func getDriveHwInfo(partDevice string) (info driveHwInfo, err error) {
 	}
 
 	var data []byte
-	data, err = ioutil.ReadFile(devPath)
+	data, err = os.ReadFile(devPath)
 	if err != nil {
 		return
 	}
@@ -452,8 +451,9 @@ func GetSysConfig(_ context.Context, addr string) SysConfig {
 		limits, err := proc.Limits()
 		if err != nil {
 			sc.Error = "rlimit: " + err.Error()
+		} else {
+			sc.Config["rlimit-max"] = limits.OpenFiles
 		}
-		sc.Config["rlimit-max"] = limits.OpenFiles
 	}
 
 	zone, _ := time.Now().Zone()
@@ -469,6 +469,18 @@ func GetSysConfig(_ context.Context, addr string) SysConfig {
 
 	sc.Config["thp-config"] = getTHPConfigs()
 
+	procCmdLine, err := getProcCmdLine()
+	if err != nil {
+		errMsg := "proc-cmdline: " + err.Error()
+		if len(sc.Error) == 0 {
+			sc.Error = errMsg
+		} else {
+			sc.Error = sc.Error + ", " + errMsg
+		}
+	} else {
+		sc.Config["proc-cmdline"] = procCmdLine
+	}
+
 	return sc
 }
 
@@ -497,6 +509,14 @@ func getTHPConfigs() map[string]string {
 	return configs
 }
 
+func getProcCmdLine() ([]string, error) {
+	fs, err := procfs.NewDefaultFS()
+	if err != nil {
+		return nil, err
+	}
+	return fs.CmdLine()
+}
+
 func captureTHPConfig(configs map[string]string, filePath string, cfgName string) {
 	errFieldName := cfgName + "_error"
 	data, err := os.ReadFile(filePath)
