@@ -23,7 +23,7 @@ import (
 	"context"
 	"encoding/json"
 	"errors"
-	"io/ioutil"
+	"io"
 	"net/http"
 	"net/url"
 	"regexp"
@@ -102,7 +102,7 @@ func (adm *AdminClient) AccountInfo(ctx context.Context, opts AccountOpts) (Acco
 	// Unmarshal the server's json response
 	var accountInfo AccountInfo
 
-	respBytes, err := ioutil.ReadAll(resp.Body)
+	respBytes, err := io.ReadAll(resp.Body)
 	if err != nil {
 		return AccountInfo{}, err
 	}
@@ -235,7 +235,7 @@ func (adm *AdminClient) GetUserInfo(ctx context.Context, name string) (u UserInf
 		return u, httpRespToErrorResponse(resp)
 	}
 
-	b, err := ioutil.ReadAll(resp.Body)
+	b, err := io.ReadAll(resp.Body)
 	if err != nil {
 		return u, err
 	}
@@ -381,6 +381,9 @@ func (r *AddServiceAccountReq) Validate() error {
 	if err != nil {
 		return err
 	}
+	if r.Expiration != nil && r.Expiration.Before(time.Now()) {
+		return errors.New("the expiration time should be in the future")
+	}
 	return validateSADescription(r.Description)
 }
 
@@ -488,6 +491,10 @@ func (u *UpdateServiceAccountReq) Validate() error {
 	if err := validateSAName(u.NewName); err != nil {
 		return err
 	}
+
+	if u.NewExpiration != nil && u.NewExpiration.Before(time.Now()) {
+		return errors.New("the expiration time should be in the future")
+	}
 	return validateSADescription(u.NewDescription)
 }
 
@@ -530,8 +537,13 @@ func (adm *AdminClient) UpdateServiceAccount(ctx context.Context, accessKey stri
 }
 
 type ServiceAccountInfo struct {
-	AccessKey  string     `json:"accessKey"`
-	Expiration *time.Time `json:"expiration,omitempty"`
+	ParentUser    string     `json:"parentUser"`
+	AccountStatus string     `json:"accountStatus"`
+	ImpliedPolicy bool       `json:"impliedPolicy"`
+	AccessKey     string     `json:"accessKey"`
+	Name          string     `json:"name,omitempty"`
+	Description   string     `json:"description,omitempty"`
+	Expiration    *time.Time `json:"expiration,omitempty"`
 }
 
 // ListServiceAccountsResp is the response body of the list service accounts call
